summaryrefslogtreecommitdiff
path: root/src/game.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/game.cpp')
-rw-r--r--src/game.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/game.cpp b/src/game.cpp
index 4e3c399cd..d2d058b65 100644
--- a/src/game.cpp
+++ b/src/game.cpp
@@ -1,10 +1,10 @@
/*
* The ManaPlus Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -588,13 +588,13 @@ bool Game::saveScreenshot(SDL_Surface *const screenshot,
if (serverName.empty())
{
screenShortStr = strprintf("%s_Screenshot_%s_",
- branding.getValue("appName", "ManaPlus").c_str(),
+ branding.getValue("appName", "ManaVerse").c_str(),
buffer);
}
else
{
screenShortStr = strprintf("%s_Screenshot_%s_%s_",
- branding.getValue("appName", "ManaPlus").c_str(),
+ branding.getValue("appName", "ManaVerse").c_str(),
serverName.c_str(), buffer);
}
@@ -1,10 +1,10 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
@@ -1,10 +1,10 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify